.. decayamplitude documentation master file, created by
   sphinx-quickstart on Tue Apr  2 16:09:04 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. Welcome to decayamplitude's documentation!
.. ======================================

.. automodule:: decayamplitude
    :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. mdinclude:: ../README.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
